# Outdated!

The information and scripts in this folder are outdated. Wheels on Windows are now built automatically as part of the Anaconda build process. Refer to the information in `packaging/conda`.

Johann Rohwer, August 2021
